package com.zhongshu.reward.server.core.domain;

import com.github.microservice.components.data.mongo.mongo.domain.SuperEntity;
import com.zhongshu.reward.client.type.TimeUnitType;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.springframework.data.mongodb.core.index.Indexed;
import org.springframework.data.mongodb.core.mapping.Document;

import java.math.BigDecimal;

/**
 * 提现规则设置
 * @author wjf
 * @date 2024/8/7
 */
@Data
@Builder
@Document
@AllArgsConstructor
@NoArgsConstructor
public class TransferRuler extends SuperEntity {

    /**
     * 单笔最小提现金额
     */
    @Indexed
    private BigDecimal minTotal = BigDecimal.ZERO;

    /**
     * 单笔最大提现金额
     */
    @Indexed
    private BigDecimal maxTotal = BigDecimal.ZERO;

    /**
     * 单日最大转账金额
     */
    @Indexed
    private BigDecimal dayMaxTotal = BigDecimal.ZERO;

    /**
     * 提现手续费
     */
    @Indexed
    private BigDecimal commission = BigDecimal.ZERO;

    /**
     * 提现次数
     */
    @Indexed
    private Integer size;

    /**
     * 时间单位
     */
    @Indexed
    private TimeUnitType timeUnit;

    /**
     * 每月开始号数
     */
    @Indexed
    private Integer startDay;

    /**
     * 每月结束号数
     */
    @Indexed
    private Integer endDay;

    /**
     * 每日开始时
     */
    @Indexed
    private Integer startHour;

    /**
     * 每日开始分
     */
    @Indexed
    private Integer startMinute;

    /**
     * 每日结束时
     */
    @Indexed
    private Integer endHour;

    /**
     * 每日结束分
     */
    @Indexed
    private Integer endMinute;

}
