package com.zhongshu.reward.server.core.service;

import com.github.microservice.auth.security.helper.AuthHelper;
import com.github.microservice.core.util.result.content.ResultContent;
import com.github.microservice.core.util.result.content.ResultState;
import com.zhongshu.reward.client.model.VipUserModel;
import com.zhongshu.reward.client.model.wallet.WalletReceiptsModel;
import com.zhongshu.reward.client.type.ReceiptsStatus;
import com.zhongshu.reward.client.type.ReceiptsType;
import com.zhongshu.reward.client.type.UserType;
import com.zhongshu.reward.server.core.dao.InviteRecordDao;
import com.zhongshu.reward.server.core.dao.VipUserRecordDao;
import com.zhongshu.reward.server.core.dao.WalletDao;
import com.zhongshu.reward.server.core.dao.WalletReceiptsDao;
import com.zhongshu.reward.server.core.domain.InviteRecord;
import com.zhongshu.reward.server.core.domain.VipUserRecord;
import com.zhongshu.reward.server.core.domain.Wallet;
import com.zhongshu.reward.server.core.domain.WalletReceipts;
import com.zhongshu.reward.server.core.util.DateUtils;
import com.zhongshu.vip.client.model.param.VipUserParam;
import com.zswl.cloud.bdb.client.service.InviteReceiptsRoleFeignService;
import com.zswl.cloud.bdb.client.vo.InviteReceiptsRoleVo;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.ObjectUtils;
import org.bson.types.ObjectId;
import org.jetbrains.annotations.NotNull;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.math.BigDecimal;
import java.util.*;
import java.util.stream.Collectors;

/**
 * @author wjf
 * @date 2024/8/6
 */
@Service
@Slf4j
public class WalletReceiptsService {

    @Autowired
    WalletDao walletDao;

    @Autowired
    WalletService walletService;

    @Autowired
    WalletReceiptsDao walletReceiptsDao;

    @Autowired
    VipUserRecordDao vipUserRecordDao;

    @Autowired
    InviteRecordDao inviteRecordDao;

    @Autowired
    AuthHelper authHelper;

    @Autowired
    InviteReceiptsRoleFeignService inviteReceiptsRoleFeignService;

    /**
     * 查询即将到账
     */
    public Object listByWallet(){
        String userId = authHelper.getCurrentUser().getUserId();
        Wallet wallet = walletService.getWalletByUserId(userId);
        List<WalletReceipts> list = walletReceiptsDao.findByWallet_IdAndStatusOrderByCreateTimeDesc(wallet.getId(), ReceiptsStatus.WAIT);
        return ResultContent.buildContent(list.stream().map(this::toModel).collect(Collectors.toList()));
    }

    /**
     * 即将到账详情
     * @param receiptsId 账单id
     */
    public Object receiptsDetail(String receiptsId){
        WalletReceipts walletReceipts = walletReceiptsDao.findTop1ById(receiptsId);
        if (ObjectUtils.isEmpty(walletReceipts)){
            return ResultContent.build(ResultState.Fail, "记录不存在");
        }
        VipUserRecord vipUserRecord = walletReceipts.getVipUserRecord();
        VipUserModel vipUserModel = new VipUserModel();
        BeanUtils.copyProperties(vipUserRecord, vipUserModel);
        BeanUtils.copyProperties(walletReceipts, vipUserModel);
        InviteRecord inviteRecord = inviteRecordDao.findTopByUserIdOrderByCreateTime(walletReceipts.getUserId());
        if (ObjectUtils.isNotEmpty(inviteRecord)){
            vipUserModel.setReceiptsTime(inviteRecord.getRegisterTime());
            vipUserModel.setPhone(inviteRecord.getPhone());
        }
        return ResultContent.buildContent(vipUserModel);
    }

    /**
     * 邀请奖励明细
     * @param year 年
     * @param month 月
     * @return
     */
    public Object rewardDetail(Integer year, Integer month){
        String userId = authHelper.getCurrentUser().getUserId();
        Long monthStartTime = DateUtils.getMonthStartTime(year, month);
        Long monthEndTime = DateUtils.getMonthEndTime(year, month);
        List<WalletReceipts> walletReceipts = walletReceiptsDao.inviteDetail(userId, monthStartTime, monthEndTime);
        return ResultContent.buildContent(walletReceipts.stream().map(this::toVipUserModel).collect(Collectors.toList()));
    }

    private VipUserModel toVipUserModel(WalletReceipts walletReceipts) {
        VipUserModel vipUserModel = new VipUserModel();
        if (ObjectUtils.isNotEmpty(walletReceipts)){
            VipUserRecord vipUserRecord = walletReceipts.getVipUserRecord();
            BeanUtils.copyProperties(vipUserRecord, vipUserModel);
            BeanUtils.copyProperties(walletReceipts, vipUserModel);
        }
        return vipUserModel;
    }

    WalletReceiptsModel toModel(WalletReceipts walletReceipts){
        WalletReceiptsModel model = new WalletReceiptsModel();
        if (null != walletReceipts){
            BeanUtils.copyProperties(walletReceipts, model, "wallet");
            model.setWalletId(walletReceipts.getWallet().getId());
        }
        return model;
    }
}
